@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
-Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
+Copyright (C) 2016, 2017, 2018, 2019, 2020 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -19,6 +19,58 @@ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
+
+This module contains equations for modeling flow where density changes
+significantly during the process - compressible flow. Also included are
+equations for choked flow - the phenomenon where the velocity of a fluid
+reaches its speed of sound.
+
+For reporting bugs, adding feature requests, or submitting pull requests,
+please use the `GitHub issue tracker <https://github.com/CalebBell/fluids/>`_
+or contact the author at Caleb.Andrew.Bell@gmail.com.
+
+
+.. contents:: :local:
+
+Compression Processes
+---------------------
+.. autofunction:: isothermal_work_compression
+.. autofunction:: isentropic_work_compression
+.. autofunction:: isentropic_T_rise_compression
+.. autofunction:: isentropic_efficiency
+.. autofunction:: polytropic_exponent
+
+Compressible Flow
+-----------------
+.. autofunction:: isothermal_gas
+
+Emperical Compressible Flow
+---------------------------
+.. autofunction:: Panhandle_A
+.. autofunction:: Panhandle_B
+.. autofunction:: Weymouth
+.. autofunction:: Spitzglass_high
+.. autofunction:: Spitzglass_low
+.. autofunction:: Oliphant
+.. autofunction:: Fritzsche
+.. autofunction:: Muller
+.. autofunction:: IGT
+
+Critical Flow
+-------------
+.. autofunction:: T_critical_flow
+.. autofunction:: P_critical_flow
+.. autofunction:: is_critical_flow
+.. autofunction:: P_isothermal_critical_flow
+.. autofunction:: P_upstream_isothermal_critical_flow
+
+Stagnation Point
+----------------
+.. autofunction:: stagnation_energy
+.. autofunction:: P_stagnation
+.. autofunction:: T_stagnation
+.. autofunction:: T_stagnation_ideal
+
 """
 
 from __future__ import division
@@ -80,12 +132,12 @@ def isothermal_work_compression(P1, P2, T, Z=1.0):
     An average compressibility factor can be used where Z changes. For further
     accuracy, this expression can be used repeatedly with small changes in
     pressure and the work from each step summed.
-    
-    This is the best possible case for compression; all actual compresssors 
+
+    This is the best possible case for compression; all actual compresssors
     require more work to do the compression.
-    
+
     By making the compression take a large number of stages and cooling the gas
-    between stages, this can be approached reasonable closely. Integrally 
+    between stages, this can be approached reasonable closely. Integrally
     geared compressors are often used for this purpose.
 
     Examples
@@ -104,16 +156,16 @@ def isothermal_work_compression(P1, P2, T, Z=1.0):
 
 def isentropic_work_compression(T1, k, Z=1.0, P1=None, P2=None, W=None, eta=None):
     r'''Calculation function for dealing with compressing or expanding a gas
-    going through an isentropic, adiabatic process assuming constant Cp and Cv. 
-    The polytropic model is the same equation; just provide `n` instead of `k` 
-    and use a polytropic efficiency for `eta` instead of a isentropic 
+    going through an isentropic, adiabatic process assuming constant Cp and Cv.
+    The polytropic model is the same equation; just provide `n` instead of `k`
+    and use a polytropic efficiency for `eta` instead of a isentropic
     efficiency. Can calculate any of the following, given all the other inputs:
 
     * W, Work of compression
-    * P2, Pressure after compression 
+    * P2, Pressure after compression
     * P1, Pressure before compression
     * eta, isentropic efficiency of compression
-    
+
     .. math::
         W = \left(\frac{k}{k-1}\right)ZRT_1\left[\left(\frac{P_2}{P_1}
         \right)^{(k-1)/k}-1\right]/\eta_{isentropic}
@@ -242,7 +294,7 @@ def isentropic_T_rise_compression(T1, P1, P2, k, eta=1):
 
     Notes
     -----
-    For the ideal case (`eta`=1), the model simplifies to:
+    For the ideal case of `eta` = 1, the model simplifies to:
 
     .. math::
         \frac{T_2}{T_1} = \left(\frac{P_2}{P_1}\right)^{(k-1)/k}
@@ -322,7 +374,7 @@ def isentropic_efficiency(P1, P2, k, eta_s=None, eta_p=None):
 
 def polytropic_exponent(k, n=None, eta_p=None):
     r'''Calculates one of:
-    
+
         * Polytropic exponent from polytropic efficiency
         * Polytropic efficiency from the polytropic exponent
 
@@ -486,7 +538,7 @@ def P_isothermal_critical_flow(P, fd, D, L):
     Examples
     --------
     >>> P_isothermal_critical_flow(P=1E6, fd=0.00185, L=1000., D=0.5)
-    389699.7317645518
+    389699.73176
 
     References
     ----------
@@ -506,7 +558,7 @@ def P_upstream_isothermal_critical_flow(P, fd, D, L):
     --------
     >>> P_upstream_isothermal_critical_flow(P=389699.7317645518, fd=0.00185,
     ... L=1000., D=0.5)
-    1000000.0000000001
+    1000000.00000
     """
     lambertw_term = float(lambertw(-exp(-(fd*L+D)/D), -1).real)
     return exp(-0.5*(D*lambertw_term+fd*L+D)/D)*P
@@ -786,28 +838,28 @@ def isothermal_gas(rho, fd, P1=None, P2=None, L=None, D=None, m=None):
     The 2 multiplied by the logarithm is often shown  as a power of the
     pressure ratio; this is only the case when the pressure ratio is raised to
     the power of 2 before its logarithm is taken.
-    
+
     A number of limitations exist for this model:
-        
+
         * Density dependence is that of an ideal gas.
         * If calculating the pressure drop, the average gas density cannot
           be known immediately; iteration must be used to correct this.
         * The friction factor depends on both the gas density and velocity,
           so it should be solved for iteratively as well. It changes throughout
           the pipe as the gas expands and velocity increases.
-        * The model is not easily adapted to include elevation effects due to 
+        * The model is not easily adapted to include elevation effects due to
           the acceleration term included in it.
         * As the gas expands, it will change temperature slightly, further
           altering the density and friction factor.
-         
-    There are many commercial packages which perform the actual direct 
+
+    There are many commercial packages which perform the actual direct
     integration of the flow, such as OLGA Dynamic Multiphase Flow Simulator,
     or ASPEN Hydraulics.
-    
+
     This expression has also been presented with the ideal gas assumption
-    directly incorporated into it [4]_ (note R is the specific gas constant, in 
+    directly incorporated into it [4]_ (note R is the specific gas constant, in
     units of J/kg/K):
-        
+
     .. math::
         \dot m^2 = \frac{\left(\frac{\pi D^2}{4}\right)^2
         \left(P_1^2-P_2^2\right)}{RT\left(f_d\frac{L}{D} + 2\ln\frac{P_1}{P_2}
@@ -1580,7 +1632,7 @@ pressure, downstream pressure, diameter, or length; all other inputs \
 must be provided.')
 
 
-def Fritzsche(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7, 
+def Fritzsche(SG, Tavg, L=None, D=None, P1=None, P2=None, Q=None, Ts=288.7,
               Ps=101325., Zavg=1.0, E=1.0):
     r'''Calculation function for dealing with flow of a compressible gas in a
     pipeline with the Fritzsche formula. Can calculate any of the following,
