@@ -26,7 +26,7 @@ from __future__ import division
 __all__ = ['get_clean_isd_history', 'IntegratedSurfaceDatabaseStation',
            'get_closest_station', 'get_station_year_text', 'gsod_day_parser',
            'StationDataGSOD', 'heating_degree_days', 'cooling_degree_days', 'stations',
-#           'geopy_geolocator', 'geopy_cache', 'SimpleGeolocatorCache', 
+#           'geopy_geolocator', 'geopy_cache', 'SimpleGeolocatorCache',
            'geocode']
 
 try: # pragma: no cover
@@ -53,7 +53,7 @@ try: # pragma: no cover
 except ImportError: # pragma: no cover
     from urllib2 import urlopen
     from urllib2 import HTTPError
-    
+
 try:  # pragma: no cover
     from appdirs import user_data_dir, user_config_dir
     data_dir = user_config_dir('fluids')
@@ -82,7 +82,7 @@ geolocator_disk_cache_loc = os.path.join(data_dir, geolocator_disk_cache_name)
 
 simple_geopy_cache = None
 
-geopy_missing_msg = '''Geocoder module `geopy` is required for this 
+geopy_missing_msg = '''Geocoder module `geopy` is required for this
 functionality.'''
 
 def geopy_geolocator():
@@ -132,7 +132,7 @@ class SimpleGeolocatorCache(object):
         cursor = self.connection.cursor()
         cursor.execute('SELECT latitude, longitude FROM geopy WHERE address=?', (address, ))
         res = cursor.fetchone()
-        if res is None: 
+        if res is None:
             return None
         return res
 
@@ -152,19 +152,19 @@ def geocode(address):
     ----------
     address : str
         Search string to retrieve the location, [-]
-        
+
     Returns
     -------
     latitude : float
         Latitude of address, [degrees]
     longitude : float
         Longitude of address, [degrees]
-        
+
     Notes
     -----
     If a query has been retrieved before, this function will take under 1 ms;
     it takes several seconds otherwise.
-    
+
     Examples
     --------
     >>> geocode('Fredericton, NB') # doctest: +SKIP
@@ -191,7 +191,7 @@ def geocode(address):
             pass
         return (location.latitude, location.longitude)
 
-    
+
 
 folder = os.path.join(os.path.dirname(__file__), 'data')
 
@@ -206,13 +206,13 @@ def heating_degree_days(T, T_base=291.4833333333333, truncate=True):
     ----------
     T : float
         Measured temperature; sometimes an average over a length of time is used,
-        other times the average of the lowest and highest temperature in a 
+        other times the average of the lowest and highest temperature in a
         period are used, [K]
     T_base : float, optional
         Reference temperature for the degree day calculation, defaults
         to 65 °F (18.33 °C, 291.483 K), the value most used in the US, [K]
     truncate : bool
-        If truncate is True, no negative values will be returned; if negative, 
+        If truncate is True, no negative values will be returned; if negative,
         the value is truncated to 0, [-]
 
     Returns
@@ -223,10 +223,10 @@ def heating_degree_days(T, T_base=291.4833333333333, truncate=True):
 
     Notes
     -----
-    Some common base temperatures are 18 °C (Canada), 15.5 °C (EU), 
+    Some common base temperatures are 18 °C (Canada), 15.5 °C (EU),
     17 °C (Denmark, Finland), 12 °C Switzerland. The base temperature
     should always be presented with the results.
-    
+
     The time unit does not have to be days; it can be any time unit, and the
     calculation behaves the same.
 
@@ -234,16 +234,16 @@ def heating_degree_days(T, T_base=291.4833333333333, truncate=True):
     --------
     >>> heating_degree_days(303.8)
     12.31666666666672
-    
+
     >>> heating_degree_days(273)
     0.0
-    
+
     >>> heating_degree_days(322, T_base=300)
     22
 
     References
     ----------
-    .. [1] "Heating Degree Day." Wikipedia, January 24, 2018. 
+    .. [1] "Heating Degree Day." Wikipedia, January 24, 2018.
        https://en.wikipedia.org/w/index.php?title=Heating_degree_day&oldid=822187764.
     '''
     dd = T - T_base
@@ -262,13 +262,13 @@ def cooling_degree_days(T, T_base=283.15, truncate=True):
     ----------
     T : float
         Measured temperature; sometimes an average over a length of time is used,
-        other times the average of the lowest and highest temperature in a 
+        other times the average of the lowest and highest temperature in a
         period are used, [K]
     T_base : float, optional
         Reference temperature for the degree day calculation, defaults
         to 10 °C, 283.15 K, a common value, [K]
     truncate : bool
-        If truncate is True, no negative values will be returned; if negative, 
+        If truncate is True, no negative values will be returned; if negative,
         the value is truncated to 0, [-]
 
     Returns
@@ -280,7 +280,7 @@ def cooling_degree_days(T, T_base=283.15, truncate=True):
     Notes
     -----
     The base temperature should always be presented with the results.
-    
+
     The time unit does not have to be days; it can be time unit, and the
     calculation behaves the same.
 
@@ -288,16 +288,16 @@ def cooling_degree_days(T, T_base=283.15, truncate=True):
     --------
     >>> cooling_degree_days(250)
     33.14999999999998
-    
+
     >>> cooling_degree_days(300)
     0.0
-    
+
     >>> cooling_degree_days(250, T_base=300)
     50
 
     References
     ----------
-    .. [1] "Heating Degree Day." Wikipedia, January 24, 2018. 
+    .. [1] "Heating Degree Day." Wikipedia, January 24, 2018.
        https://en.wikipedia.org/w/index.php?title=Heating_degree_day&oldid=822187764.
     '''
     dd = T_base - T
@@ -379,13 +379,13 @@ class IntegratedSurfaceDatabaseStation(object):
     """
     __slots__ = ['USAF', 'WBAN', 'NAME', 'CTRY', 'ST', 'ICAO', 'LAT', 'LON',
                  'ELEV', 'BEGIN', 'END', 'raw_data', 'parsed_data']
-    
+
     def __repr__(self):
         s = ('<Weather station registered in the Integrated Surface Database, '
             'name %s, country %s, USAF %s, WBAN %s, coords (%s, %s) '
             'Weather data from %s to %s>' )
         return s%(self.NAME, self.CTRY, self.USAF, self.WBAN, self.LAT, self.LON, str(self.BEGIN)[0:4], str(self.END)[0:4])
-    
+
     def __init__(self, USAF, WBAN, NAME, CTRY, ST, ICAO, LAT, LON, ELEV, BEGIN,
                  END):
         try:
@@ -402,7 +402,7 @@ class IntegratedSurfaceDatabaseStation(object):
         self.ELEV = ELEV
         self.BEGIN = int(BEGIN)
         self.END = int(END)
-        
+
 
 class StationDataGSOD(object):
     # Holds data, caches and retrieves data
@@ -410,9 +410,9 @@ class StationDataGSOD(object):
         self.station = station
         self.begin = datetime.datetime.strptime(str(self.station.BEGIN), '%Y%m%d')
         self.end = datetime.datetime.strptime(str(self.station.END), '%Y%m%d')
-        
+
         self.year_range = range(self.begin.year, self.end.year + 1)
-        
+
 #         Would be nice to create these later, when using a download_data method
         self.raw_text = {}
         self.raw_data = {}
@@ -420,7 +420,7 @@ class StationDataGSOD(object):
         self.load_empty_vectors()
         self.download_data()
         self.parse_data()
-        
+
     def load_empty_vectors(self):
         for year in self.year_range:
             days_in_year = 366 if isleap(year) else 365
@@ -437,7 +437,7 @@ class StationDataGSOD(object):
                     self.raw_text[year] = year_data
                 except:
                     pass
-    
+
     def parse_data(self):
         for year, data in self.raw_text.items():
             if data is not None:
@@ -446,18 +446,18 @@ class StationDataGSOD(object):
                     parsed = gsod_day_parser(line)
                     doy = parsed.DATE.timetuple().tm_yday-1
                     days[doy] = parsed
-                    
+
     def coldest_month(self, older_year=None, newer_year=None, minimum_days=23):
         # Tested
         month_data = self.month_average_temperature(older_year=older_year,
-                                                    newer_year=newer_year, 
+                                                    newer_year=newer_year,
                                                     minimum_days=minimum_days)
         return month_data.index(min(month_data))
-    
+
     def warmest_month(self, older_year=None, newer_year=None, minimum_days=23):
         # Tested
         month_data = self.month_average_temperature(older_year=older_year,
-                                                    newer_year=newer_year, 
+                                                    newer_year=newer_year,
                                                     minimum_days=minimum_days)
         return month_data.index(max(month_data))
 
@@ -472,7 +472,7 @@ class StationDataGSOD(object):
         # Take years, make them inclusive; add minimum valid days.
         year_month_averages = {}
         year_month_counts = {}
-        
+
         for year, data in self.parsed_data.items():
             if not (older_year <= year <= newer_year):
                 continue # Ignore out-of-range years easily
@@ -485,14 +485,14 @@ class StationDataGSOD(object):
                 # Don't do these comparisons to make it fast
                 if day.DATE.year < older_year or day.DATE.year > newer_year:
                     continue # Ignore out-of-range days as possible
-                    
+
                 T = day.TEMP
                 if T is None:
                     continue
                 # Cache these lookups
                 year_month_averages[year][day.DATE.month-1] += T
                 year_month_counts[year][day.DATE.month-1] += 1
-            
+
             for month in range(12):
                 count = year_month_counts[year][month]
                 if count < minimum_days:
@@ -500,17 +500,17 @@ class StationDataGSOD(object):
                 else:
                     ans = year_month_averages[year][month]/count
                 year_month_averages[year][month] = ans
-                
+
         # Compute the average of the month
         actual_averages = [0.0]*12
         actual_averages_counts = [0]*12
         for year, average in year_month_averages.items():
             for month in range(12):
                 if average is not None and average[month] is not None:
-                    count = actual_averages_counts[month] 
+                    count = actual_averages_counts[month]
                     if count is None:
                         count = 1
-                    else: 
+                    else:
                         count += 1
                     actual_averages_counts[month] = count
                     month_average_sum = actual_averages[month]
@@ -519,10 +519,10 @@ class StationDataGSOD(object):
                     else:
                         month_average_sum += average[month]
                     actual_averages[month] = month_average_sum
-                    
+
         for month in range(12):
             actual_averages[month] = actual_averages[month]/actual_averages_counts[month]
-                    
+
         # Don't set anything as properties - too many variables used in calculating thems
         # Speed is not that important.
         if include_yearly:
@@ -536,7 +536,7 @@ class StationDataGSOD(object):
         # Take years, make them inclusive; add minimum valid days.
         year_month_averages = {}
         year_month_counts = {}
-        
+
         for year, data in self.parsed_data.items():
             if not (older_year <= year <= newer_year):
                 continue # Ignore out-of-range years easily
@@ -549,14 +549,14 @@ class StationDataGSOD(object):
                 # Don't do these comparisons to make it fast
                 if day.DATE.year < older_year or day.DATE.year > newer_year:
                     continue # Ignore out-of-range days as possible
-                    
+
                 wind_speed = day.WDSP
                 if wind_speed is None:
                     continue
                 # Cache these lookups
                 year_month_averages[year][day.DATE.month-1] += wind_speed
                 year_month_counts[year][day.DATE.month-1] += 1
-            
+
             for month in range(12):
                 count = year_month_counts[year][month]
                 if count < minimum_days:
@@ -564,17 +564,17 @@ class StationDataGSOD(object):
                 else:
                     ans = year_month_averages[year][month]/count
                 year_month_averages[year][month] = ans
-                
+
         # Compute the average of the month
         actual_averages = [0.0]*12
         actual_averages_counts = [0]*12
         for year, average in year_month_averages.items():
             for month in range(12):
                 if average is not None and average[month] is not None:
-                    count = actual_averages_counts[month] 
+                    count = actual_averages_counts[month]
                     if count is None:
                         count = 1
-                    else: 
+                    else:
                         count += 1
                     actual_averages_counts[month] = count
                     month_average_sum = actual_averages[month]
@@ -583,10 +583,10 @@ class StationDataGSOD(object):
                     else:
                         month_average_sum += average[month]
                     actual_averages[month] = month_average_sum
-                    
+
         for month in range(12):
             actual_averages[month] = actual_averages[month]/actual_averages_counts[month]
-                    
+
         # Don't set anything as properties - too many variables used in calculating thems
         # Speed is not that important.
         if include_yearly:
@@ -608,7 +608,7 @@ class StationDataGSOD(object):
 
 stations = []
 _latlongs = []
-'''Read in the parsed data into 
+'''Read in the parsed data into
 1) a list of latitudes and longitudes, temporary, which will get converted to
 a numpy array for use in KDTree
 2) a list of IntegratedSurfaceDatabaseStation objects; the query will return
@@ -642,7 +642,7 @@ station_count = len(stations)
 kd_tree = cKDTree(_latlongs) # _latlongs must be unchanged as data is not copied
 
 
-def get_closest_station(latitude, longitude, minumum_recent_data=20140000, 
+def get_closest_station(latitude, longitude, minumum_recent_data=20140000,
                         match_max=100):
     """Query function to find the nearest weather station to a particular set of
     coordinates. Optionally allows for a recent date by which the station is
@@ -659,24 +659,24 @@ def get_closest_station(latitude, longitude, minumum_recent_data=20140000,
         weather data than; format YYYYMMDD; set this to 0 to not restrict data
         by date.
     match_max : int, optional
-        The maximum number of results in the KDTree to search for before 
+        The maximum number of results in the KDTree to search for before
         applying the filtering criteria; an internal parameter which is
         increased automatically if the default value is insufficient [-]
-        
+
     Returns
     -------
     station : IntegratedSurfaceDatabaseStation
         Instance of IntegratedSurfaceDatabaseStation which was nearest
         to the requested coordinates and with sufficiently recent data
         available [-]
-        
+
     Notes
     -----
-    Searching for 100 stations is a reasonable choice as it takes, ~70 
-    microseconds vs 50 microsecond to find only 1 station. The search does get 
+    Searching for 100 stations is a reasonable choice as it takes, ~70
+    microseconds vs 50 microsecond to find only 1 station. The search does get
     slower as more points are requested. Bad data is returned from a KDTree
     search if more points are requested than are available.
-    
+
     Examples
     --------
     >>> get_closest_station(51.02532675, -114.049868485806, 20150000)
@@ -686,7 +686,7 @@ def get_closest_station(latitude, longitude, minumum_recent_data=20140000,
     # Searching for 100 stations is fine, 70 microseconds vs 50 microsecond for 1
     # but there's little point for more points, it gets slower.
     # bad data is returned if k > station_count
-    distances, indexes = kd_tree.query([latitude, longitude], k=min(match_max, station_count)) 
+    distances, indexes = kd_tree.query([latitude, longitude], k=min(match_max, station_count))
     #
     for i in indexes:
         latlon = _latlongs[i]
@@ -727,43 +727,45 @@ def get_station_year_text(WMO, WBAN, year):
     gsod_year_dir = os.path.join(data_dir, 'gsod', str(year))
     path = os.path.join(gsod_year_dir, station + '.op')
     if os.path.exists(path):
-        data = open(path).read()
-        if data and data != 'Exception':
-            return data
-        else:
-            raise ValueError(data)
-        
-    toget = ('ftp://ftp.ncdc.noaa.gov/pub/data/gsod/' + str(year) + '/' 
+        with open(path, 'r') as f:
+            data = f.read()
+            if data and data != 'Exception':
+                return data
+            else:
+                raise ValueError(data)
+
+    toget = ('ftp://ftp.ncdc.noaa.gov/pub/data/gsod/' + str(year) + '/'
              + station + '-' + str(year) +'.op.gz')
     try:
         data = urlopen(toget, timeout=5)
     except Exception as e:
         if not os.path.exists(gsod_year_dir):
             os.makedirs(gsod_year_dir)
-        open(path, 'w').write('Exception')
+        with open(path, 'w') as f:
+            f.write('Exception')
         raise ValueError('Could not obtain desired data; check '
                         'if the year has data published for the '
                         'specified station and the station was specified '
                         'in the correct form. The full error is %s' %(e))
-        
+
     data = data.read()
     data_thing = StringIO(data)
 
     f = gzip.GzipFile(fileobj=data_thing, mode="r")
     year_station_data = f.read()
-    try: 
+    try:
         year_station_data = year_station_data.decode('utf-8')
     except:
         pass
-    
+
     # Cache the data for future use
     if not os.path.exists(gsod_year_dir):
         os.makedirs(gsod_year_dir)
     open(path, 'w').write(year_station_data)
-    
-    
+
+
     return year_station_data
-    
+
 
 
 gsod_fields = ['DATE', # 15-18 int year; 19-22 int month/day
@@ -781,12 +783,12 @@ gsod_fields = ['DATE', # 15-18 int year; 19-22 int month/day
                'WDSP_COUNT', # 85-86 Int. Number of observations used in calculating mean wind speed
                'MXSPD', # 89-93 Real Maximum sustained wind speed reported for the day in knots to tenths. Missing = 999.9
                'GUST', # 96-100 Real Maximum wind gust reported for the day in knots to tenths. Missing = 999.9
-               'MAX', # 103-108 Real Maximum temperature reported during the 
+               'MAX', # 103-108 Real Maximum temperature reported during the
                       # day in Fahrenheit to tenths--time of max temp report varies by country and
                       # region, so this will sometimes not be the max for the calendar day.
                       # Missing = 9999.9; FLAG of '*' is present on 109-109!
                'MIN', # 111-116 Real Minimum temperature reported during the day in Fahrenheit to tenths--time of min
-                      # temp report varies by country and region, so this will sometimes not be 
+                      # temp report varies by country and region, so this will sometimes not be
                       # the min for the calendar day. Missing = 9999.9 FLAG of '*' is present on 117-117!
                'PRCP', # 119-123 Real Total precipitation (rain and/or melted snow) reported during the day in inches
                        # and hundredths; will usually not end with the midnight observation--i.e.,
@@ -803,14 +805,14 @@ gsod_fields = ['DATE', # 15-18 int year; 19-22 int month/day
                         # Snow or Ice Pellets ('S' - 3rd digit).
                         # Hail ('H' - 4th digit).
                         # Thunder ('T' - 5th digit).
-                        # Tornado or Funnel Cloud ('T' - 6th digit).              
+                        # Tornado or Funnel Cloud ('T' - 6th digit).
               ]
 # Use TEMP and DEWP and STP to calculate wet bulb temperatures
 # Values to be converted to floats always
-gsod_float_fields = ('TEMP', 'DEWP', 'SLP', 'STP', 'VISIB', 'WDSP', 'MXSPD', 
+gsod_float_fields = ('TEMP', 'DEWP', 'SLP', 'STP', 'VISIB', 'WDSP', 'MXSPD',
                      'GUST', 'MAX', 'MIN', 'PRCP', 'SNDP')
 # Values to be converted to ints always
-gsod_int_fields = ('TEMP_COUNT', 'DEWP_COUNT', 'SLP_COUNT', 'STP_COUNT', 
+gsod_int_fields = ('TEMP_COUNT', 'DEWP_COUNT', 'SLP_COUNT', 'STP_COUNT',
                    'VISIB_COUNT', 'WDSP_COUNT')
 
 # Values which signify flags
@@ -818,7 +820,7 @@ gsod_flag_chars = '*ABCDEFGHI'
 # Values which should be converted to None, as normally there is no value
 gsod_bad_values = set(['99.99', '999.9', '9999.9'])
 
-gsod_indicator_names = ['fog', 'rain', 'snow_ice', 'hail', 'thunder', 
+gsod_indicator_names = ['fog', 'rain', 'snow_ice', 'hail', 'thunder',
                         'tornado']
 five_ninths = 5.0/9.0
 
@@ -857,21 +859,21 @@ def gsod_day_parser(line, SI=True, to_datetime=True):
         namedtuple with fields described in the source (all values in SI units,
         if `SI` is True, i.e. meters, m/s, Kelvin, Pascal; otherwise the
         original unit set is used), [-]
-    """    
+    """
     # Ignore STN--- and WBAN, 8-12 characters
     fields = line.strip().split()[2:]
-    # For the case the field is blank, set it to None; strip it either way 
+    # For the case the field is blank, set it to None; strip it either way
     for i in range(len(fields)):
         field = fields[i].strip()
         if not field:
             field = None
-        fields[i] = field 
+        fields[i] = field
 
     obj = dict(zip(gsod_fields, fields))
     # Convert the date to a datetime object if specified
     if to_datetime and obj['DATE'] is not None:
         obj['DATE'] = datetime.datetime.strptime(obj['DATE'], '%Y%m%d')
-                
+
     # Parse float values as floats
     for field in gsod_float_fields:
         value = obj[field].rstrip(gsod_flag_chars)
@@ -880,7 +882,7 @@ def gsod_day_parser(line, SI=True, to_datetime=True):
         else:
             value = float(value)
         obj[field] = value
-        
+
     if SI:
         # All temperatures are in deg F
         for field in ('TEMP', 'DEWP', 'MAX', 'MIN'):
@@ -898,7 +900,7 @@ def gsod_day_parser(line, SI=True, to_datetime=True):
         if obj['SNDP'] is not None:
             obj['SNDP'] = obj['SNDP']*inch
         if obj['WDSP'] is not None:
-            obj['WDSP'] = obj['WDSP']*knot 
+            obj['WDSP'] = obj['WDSP']*knot
         if obj['MXSPD'] is not None:
             obj['MXSPD'] = obj['MXSPD']*knot
         if obj['GUST'] is not None:
@@ -910,7 +912,7 @@ def gsod_day_parser(line, SI=True, to_datetime=True):
 
     # Parse int values as ints
     for field in gsod_int_fields:
-        value = obj[field] 
+        value = obj[field]
         if value is not None:
             obj[field] = int(value)
 
