@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
-Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
+Copyright (C) 2016, 2017, 2018, 2019, 2020 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -19,6 +19,48 @@ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
+
+This module contains correlations for the drag coefficient `Cd` of a particle
+moving in a fluid. Numerical solvers for terminal velocity and an
+integrator for particle position over time are included also.
+
+For reporting bugs, adding feature requests, or submitting pull requests,
+please use the `GitHub issue tracker <https://github.com/CalebBell/fluids/>`_
+or contact the author at Caleb.Andrew.Bell@gmail.com.
+
+.. contents:: :local:
+
+Interfaces to Drag Models
+-------------------------
+.. autofunction:: drag_sphere
+.. autofunction:: v_terminal
+.. autofunction:: integrate_drag_sphere
+.. autofunction:: time_v_terminal_Stokes
+.. autofunction:: drag_sphere_methods
+
+Drag Correlations
+-----------------
+.. autofunction:: Stokes
+.. autofunction:: Barati
+.. autofunction:: Barati_high
+.. autofunction:: Khan_Richardson
+.. autofunction:: Morsi_Alexander
+.. autofunction:: Rouse
+.. autofunction:: Engelund_Hansen
+.. autofunction:: Clift_Gauvin
+.. autofunction:: Graf
+.. autofunction:: Flemmer_Banks
+.. autofunction:: Swamee_Ojha
+.. autofunction:: Yen
+.. autofunction:: Haider_Levenspiel
+.. autofunction:: Cheng
+.. autofunction:: Terfous
+.. autofunction:: Mikhailov_Freire
+.. autofunction:: Clift
+.. autofunction:: Ceylan
+.. autofunction:: Almedeij
+.. autofunction:: Morrison
+.. autofunction:: Song_Xu
 """
 
 from __future__ import division
@@ -106,9 +148,10 @@ def Barati(Re):
        Evolutionary Approach." Powder Technology 257 (May 2014): 11-19.
        doi:10.1016/j.powtec.2014.02.045.
     '''
-    Cd = (5.4856E9*tanh(4.3774E-9/Re) + 0.0709*tanh(700.6574/Re)
-    + 0.3894*tanh(74.1539/Re) - 0.1198*tanh(7429.0843/Re)
-    + 1.7174*tanh(9.9851/(Re+2.3384)) + 0.4744)
+    Re_inv = 1.0/Re
+    Cd = (5.4856E9*tanh(4.3774E-9*Re_inv) + 0.0709*tanh(700.6574*Re_inv)
+    + 0.3894*tanh(74.1539*Re_inv) - 0.1198*tanh(7429.0843*Re_inv)
+    + 1.7174*tanh(9.9851/(Re + 2.3384)) + 0.4744)
     return Cd
 
 
@@ -296,16 +339,45 @@ def Morsi_Alexander(Re):
     r'''Calculates drag coefficient of a smooth sphere using the method in
     [1]_ as described in [2]_.
 
+    If Re < 0.1:
+
     .. math::
-        C_D = \left\{ \begin{array}{ll}
-        \frac{24}{Re} & \mbox{if $Re < 0.1$}\\
-        \frac{22.73}{Re}+\frac{0.0903}{Re^2} + 3.69 & \mbox{if $0.1 < Re < 1$}\\
-        \frac{29.1667}{Re}-\frac{3.8889}{Re^2} + 1.2220 & \mbox{if $1 < Re < 10$}\\
-        \frac{46.5}{Re}-\frac{116.67}{Re^2} + 0.6167 & \mbox{if $10 < Re < 100$}\\
-        \frac{98.33}{Re}-\frac{2778}{Re^2} + 0.3644 & \mbox{if $100 < Re < 1000$}\\
-        \frac{148.62}{Re}-\frac{4.75\times10^4}{Re^2} + 0.3570 & \mbox{if $1000 < Re < 5000$}\\
-        \frac{-490.5460}{Re}+\frac{57.87\times10^4}{Re^2} + 0.46 & \mbox{if $5000 < Re < 10000$}\\
-        \frac{-1662.5}{Re}+\frac{5.4167\times10^6}{Re^2} + 0.5191 & \mbox{if $10000 < Re < 50000$}\end{array} \right.
+        C_D = \frac{24}{Re}
+
+    If 0.1 < Re < 1:
+
+    .. math::
+        C_D = \frac{22.73}{Re}+\frac{0.0903}{Re^2} + 3.69
+
+    If 1 < Re < 10:
+
+    .. math::
+        C_D = \frac{29.1667}{Re}-\frac{3.8889}{Re^2} + 1.2220
+
+    If 10 < Re < 100:
+
+    .. math::
+        C_D =\frac{46.5}{Re}-\frac{116.67}{Re^2} + 0.6167
+
+    If 100 < Re < 1000:
+
+    .. math::
+        C_D = \frac{98.33}{Re}-\frac{2778}{Re^2} + 0.3644
+
+    If 1000 < Re < 5000:
+
+    .. math::
+        C_D =  \frac{148.62}{Re}-\frac{4.75\times10^4}{Re^2} + 0.3570
+
+    If 5000 < Re < 10000:
+
+    .. math::
+        C_D = \frac{-490.5460}{Re}+\frac{57.87\times10^4}{Re^2} + 0.46
+
+    If 10000 < Re < 50000:
+
+    .. math::
+        C_D = \frac{-1662.5}{Re}+\frac{5.4167\times10^6}{Re^2} + 0.5191
 
     Parameters
     ----------
@@ -741,17 +813,50 @@ def Clift(Re):
     r'''Calculates drag coefficient of a smooth sphere using the method in
     [1]_ as described in [2]_.
 
+    If Re < 0.01:
+
     .. math::
-        C_D = \left\{ \begin{array}{ll}
-        \frac{24}{Re} + \frac{3}{16} & \mbox{if $Re < 0.01$}\\
-        \frac{24}{Re}(1 + 0.1315Re^{0.82 - 0.05\log Re}) & \mbox{if $0.01 < Re < 20$}\\
-        \frac{24}{Re}(1 + 0.1935Re^{0.6305}) & \mbox{if $20 < Re < 260$}\\
-        10^{[1.6435 - 1.1242\log Re + 0.1558[\log Re]^2} & \mbox{if $260 < Re < 1500$}\\
-        10^{[-2.4571 + 2.5558\log Re - 0.9295[\log Re]^2 + 0.1049[\log Re]^3} & \mbox{if $1500 < Re < 12000$}\\
-        10^{[-1.9181 + 0.6370\log Re - 0.0636[\log Re]^2} & \mbox{if $12000 < Re < 44000$}\\
-        10^{[-4.3390 + 1.5809\log Re - 0.1546[\log Re]^2} & \mbox{if $44000 < Re < 338000$}\\
-        9.78 - 5.3\log Re & \mbox{if $338000 < Re < 400000$}\\
-        0.19\log Re - 0.49 & \mbox{if $400000 < Re < 1000000$}\end{array} \right.
+        C_D = \frac{24}{Re} + \frac{3}{16}
+
+    If 0.01 < Re < 20:
+
+    .. math::
+        C_D = \frac{24}{Re}(1 + 0.1315Re^{0.82 - 0.05\log Re})
+
+    If 20 < Re < 260:
+
+    .. math::
+        C_D = \frac{24}{Re}(1 + 0.1935Re^{0.6305})
+
+    If 260 < Re < 1500:
+
+    .. math::
+        C_D = 10^{[1.6435 - 1.1242\log Re + 0.1558[\log Re]^2}
+
+    If 1500 < Re < 12000:
+
+    .. math::
+        C_D = 10^{[-2.4571 + 2.5558\log Re - 0.9295[\log Re]^2 + 0.1049[\log Re]^3}
+
+    If 12000 < Re < 44000:
+
+    .. math::
+        C_D = 10^{[-1.9181 + 0.6370\log Re - 0.0636[\log Re]^2}
+
+    If 44000 < Re < 338000:
+
+    .. math::
+        C_D = 10^{[-4.3390 + 1.5809\log Re - 0.1546[\log Re]^2}
+
+    If 338000 < Re < 400000:
+
+    .. math::
+        C_D = 9.78 - 5.3\log Re
+
+    If 400000 < Re < 1000000:
+
+    .. math::
+        C_D = 0.19\log Re - 0.49
 
     Parameters
     ----------
@@ -961,7 +1066,7 @@ def Song_Xu(Re, sphericity=1., S=1.):
 
     .. math::
         C_d = \frac{24}{Re\phi^{0.65}S^{0.3}}\left(1 + 0.35Re\right)^{0.44}
-        
+
     Parameters
     ----------
     Re : float
@@ -980,7 +1085,7 @@ def Song_Xu(Re, sphericity=1., S=1.):
 
     Notes
     -----
-    Notable as its experimental data and analysis is included in their 
+    Notable as its experimental data and analysis is included in their
     supporting material.
 
     Examples
@@ -990,10 +1095,10 @@ def Song_Xu(Re, sphericity=1., S=1.):
 
     References
     ----------
-    .. [1] Song, Xianzhi, Zhengming Xu, Gensheng Li, Zhaoyu Pang, and Zhaopeng 
-       Zhu. "A New Model for Predicting Drag Coefficient and Settling Velocity 
-       of Spherical and Non-Spherical Particle in Newtonian Fluid." Powder 
-       Technology 321 (November 2017): 242-50. 
+    .. [1] Song, Xianzhi, Zhengming Xu, Gensheng Li, Zhaoyu Pang, and Zhaopeng
+       Zhu. "A New Model for Predicting Drag Coefficient and Settling Velocity
+       of Spherical and Non-Spherical Particle in Newtonian Fluid." Powder
+       Technology 321 (November 2017): 242-50.
        doi:10.1016/j.powtec.2017.08.017.
     '''
     return 24/(Re*sphericity**0.65*S**0.3)*(1+0.35*Re)**0.44
@@ -1026,8 +1131,8 @@ drag_sphere_correlations = {
 def drag_sphere_methods(Re, check_ranges=True):
     r'''This function returns a list of methods that can be used to calculate
     the drag coefficient of a sphere.
-    Twenty one methods are available, all requiring only the Reynolds number of 
-    the sphere. Most methods are valid from Re=0 to Re=200,000. 
+    Twenty one methods are available, all requiring only the Reynolds number of
+    the sphere. Most methods are valid from Re=0 to Re=200,000.
 
     Examples
     --------
@@ -1046,7 +1151,7 @@ def drag_sphere_methods(Re, check_ranges=True):
     check_ranges : bool, optional
         Whether to return only correlations claiming to be valid for the given
         `Re` or not, [-]
-    
+
     Returns
     -------
     methods : list, only returned if AvailableMethods == True
@@ -1206,11 +1311,11 @@ def v_terminal(D, rhop, rho, mu, Method=None):
     0.004142497244531304
 
     Example 7-1 in GPSA handbook, 13th edition:
-        
+
     >>> from scipy.constants import *
     >>> v_terminal(D=150E-6, rhop=31.2*lb/foot**3, rho=2.07*lb/foot**3,  mu=1.2e-05)/foot
     0.4491992020345101
-    
+
     The answer reported there is 0.46 ft/sec.
 
     References
@@ -1246,15 +1351,15 @@ def v_terminal(D, rhop, rho, mu, Method=None):
 def time_v_terminal_Stokes(D, rhop, rho, mu, V0, tol=1e-14):
     r'''Calculates the time required for a particle in Stoke's regime only to
     reach terminal velocity (approximately). An infinitely long period is
-    required theoretically, but with floating points, it is possible to 
-    calculate the time required to come within a specified `tol` of that 
+    required theoretically, but with floating points, it is possible to
+    calculate the time required to come within a specified `tol` of that
     terminal velocity.
-    
+
     .. math::
-        t_{term} = -\frac{1}{18\mu}\ln \left(\frac{D^2g\rho - D^2 g \rho_p 
-        + 18\mu V_{term}}{D^2g\rho - D^2 g \rho_p + 18\mu V_0 } \right) D^2 
+        t_{term} = -\frac{1}{18\mu}\ln \left(\frac{D^2g\rho - D^2 g \rho_p
+        + 18\mu V_{term}}{D^2g\rho - D^2 g \rho_p + 18\mu V_0 } \right) D^2
         \rho_p
-    
+
     Parameters
     ----------
     D : float
@@ -1281,7 +1386,7 @@ def time_v_terminal_Stokes(D, rhop, rho, mu, V0, tol=1e-14):
     Notes
     -----
     The symbolic solution was obtained via Wolfram Alpha.
-    
+
     If a solution cannot be obtained due to floating point error at very high
     tolerance, an exception is raised - but first, the tolerance is doubled,
     up to fifty times in an attempt to obtain the highest possible precision
@@ -1290,15 +1395,15 @@ def time_v_terminal_Stokes(D, rhop, rho, mu, V0, tol=1e-14):
 
     Examples
     --------
-    >>> time_v_terminal_Stokes(D=1e-7, rhop=2200., rho=1.2, mu=1.78E-5, V0=1) 
+    >>> time_v_terminal_Stokes(D=1e-7, rhop=2200., rho=1.2, mu=1.78E-5, V0=1)
     3.1880031137871528e-06
-    >>> time_v_terminal_Stokes(D=1e-2, rhop=2200., rho=1.2, mu=1.78E-5, V0=1, 
+    >>> time_v_terminal_Stokes(D=1e-2, rhop=2200., rho=1.2, mu=1.78E-5, V0=1,
     ... tol=1e-30)
     24800.636391801996
     '''
     if tol < 1e-17:
         tol = 2e-17
-    term = D*D*g*rho - D*D*g*rhop 
+    term = D*D*g*rho - D*D*g*rhop
     denominator = term + 18.*mu*V0
     v_term_base = g*D*D*(rhop-rho)/(18.*mu)
 
@@ -1359,40 +1464,40 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
     Notes
     -----
     This can be relatively slow as drag correlations can be complex.
-    
-    There are analytical solutions available for the Stokes law regime (Re < 
+
+    There are analytical solutions available for the Stokes law regime (Re <
     0.3). They were obtained from Wolfram Alpha. [1]_ was not used in the
     derivation, but also describes the derivation fully.
-    
+
     .. math::
         V(t) = \frac{\exp(-at) (V_0 a + b(\exp(at) - 1))}{a}
-        
+
     .. math::
-        x(t) = \frac{\exp(-a t)\left[V_0 a(\exp(a t) - 1) + b\exp(a t)(a t-1) 
+        x(t) = \frac{\exp(-a t)\left[V_0 a(\exp(a t) - 1) + b\exp(a t)(a t-1)
         + b\right]}{a^2}
-    
+
     .. math::
         a = \frac{18\mu_f}{D^2\rho_p}
-    
+
     .. math::
         b = \frac{g(\rho_p-\rho_f)}{\rho_p}
-        
-    The analytical solution will automatically be used if the initial and 
+
+    The analytical solution will automatically be used if the initial and
     terminal velocity is show the particle's behavior to be laminar. Note
     that this behavior requires that the terminal velocity of the particle be
-    solved for - this adds slight (1%) overhead for the cases where particles 
+    solved for - this adds slight (1%) overhead for the cases where particles
     are not laminar.
 
     Examples
     --------
     >>> integrate_drag_sphere(D=0.001, rhop=2200., rho=1.2, mu=1.78E-5, t=0.5,
-    ... V=30, distance=True) 
+    ... V=30, distance=True)
     (9.686465044053, 7.8294546436299)
-    
+
     References
     ----------
-    .. [1] Timmerman, Peter, and Jacobus P. van der Weele. "On the Rise and 
-       Fall of a Ball with Linear or Quadratic Drag." American Journal of 
+    .. [1] Timmerman, Peter, and Jacobus P. van der Weele. "On the Rise and
+       Fall of a Ball with Linear or Quadratic Drag." American Journal of
        Physics 67, no. 6 (June 1999): 538-46. https://doi.org/10.1119/1.19320.
     '''
     # Delayed import of necessaray functions
@@ -1424,7 +1529,7 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
                 return V_end, x_end + V_end*(t - t_to_terminal)
             else:
                 return V_end
-            
+
             # This is a serious problem for small diameters
             # It would be possible to step slowly, using smaller increments
             # of time to avlid overflows. However, this unfortunately quickly
@@ -1443,7 +1548,7 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
 #                return V, x
 #            else:
 #                return V
-    
+
     Re_ish = rho*D/mu
     c1 = g*(rhop-rho)/rhop
     c2 = -0.75*rho/(D*rhop)
@@ -1462,7 +1567,7 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
     # For an accurate integration of the particle's distance traveled
     pts = 1000 if distance else 2
     ts = np.linspace(0, t, pts)
-    
+
 
     # Perform the integration
     Vs = odeint(dv_dt, [V], ts)
